aboutsummaryrefslogtreecommitdiffstats
path: root/mod/page.php
diff options
context:
space:
mode:
Diffstat (limited to 'mod/page.php')
-rw-r--r--mod/page.php42
1 files changed, 31 insertions, 11 deletions
diff --git a/mod/page.php b/mod/page.php
index 4b2b95b6a..452341cb1 100644
--- a/mod/page.php
+++ b/mod/page.php
@@ -6,16 +6,13 @@ require_once('include/page_widgets.php');
function page_init(&$a) {
// We need this to make sure the channel theme is always loaded.
- $which = argv(1);
- $profile = 0;
- $channel = $a->get_channel();
- if((local_user()) && (argc() > 2) && (argv(2) === 'view')) {
- $which = $channel['channel_address'];
- $profile = argv(1);
- }
+ $which = argv(1);
+ $profile = 0;
+ profile_load($a,$which,$profile);
- profile_load($a,$which,$profile);
+ if($a->profile['profile_uid'])
+ head_set_icon($a->profile['thumb']);
}
@@ -51,9 +48,15 @@ function page_content(&$a) {
return;
}
+ if($_REQUEST['rev'])
+ $revision = " and revision = " . intval($_REQUEST['rev']) . " ";
+ else
+ $revision = " order by revision desc ";
+
+
$r = q("select item.* from item left join item_id on item.id = item_id.iid
where item.uid = %d and sid = '%s' and service = 'WEBPAGE' and
- item_restrict = %d limit 1",
+ item_restrict = %d $revision limit 1",
intval($u[0]['channel_id']),
dbesc($page_id),
intval(ITEM_WEBPAGE)
@@ -63,8 +66,25 @@ function page_content(&$a) {
notice( t('Item not found.') . EOL);
return;
}
+dbg(1);
+ if($r[0]['layout_mid']) {
+ $l = q("select body from item where mid = '%s' and uid = %d limit 1",
+ dbesc($r[0]['layout_mid']),
+ intval($u[0]['channel_id'])
+ );
+
+ if($l) {
+ require_once('include/comanche.php');
+ comanche_parser(get_app(),$l[0]['body']);
+ }
+ }
+dbg(0);
+
+logger('layout: ' . print_r($a->layout,true));
+
+
+ // Use of widgets should be determined by Comanche, but we don't have it yet, so...
-// Use of widgets should be determined by Comanchie, but we don't have it yet, so...
if ($perms['write_pages']) {
$chan = $a->channel['channel_id'];
$who = $channel_address;
@@ -74,7 +94,7 @@ function page_content(&$a) {
xchan_query($r);
$r = fetch_post_tags($r,true);
- $a->profile = array('profile_uid' => $u[0]['channel_id']);
+
$o .= prepare_page($r[0]);
return $o;